.colLeft[data-v-9721b224]{min-width:750px}.colLeft .btn[data-v-9721b224]{margin:10px 5px 10px 5px}.colRight .searchInput[data-v-9721b224]{margin:10px 5px 10px 5px;width:300px;min-width:350px}#coverage[data-v-73a14fa6]{width:80%;height:200px;margin:30px 30px 0 30px}#info[data-v-2c9b29be]{width:80%;height:150px;margin:30px 30px 0 30px}.small-tab>.ivu-tabs>.ivu-tabs-bar{margin-bottom:0}.flow-detail{height:50vh}#tab[data-v-a14e48ee]{background-color:pink;width:100%;height:100%;margin-top:30px}#app[data-v-80a212d2]{min-width:1500px}